package com.gct.dataengine.register.config;

import com.gct.dataengine.register.properties.MutableTriggerConfigProperties;
import com.gct.dataengine.register.properties.TriggerConfigurationProperties;
import com.gct.dataengine.register.quartztask.PullTemplateTaskJob;
import com.gct.dataengine.register.quartztask.UnbindJob;
import lombok.extern.slf4j.Slf4j;
import org.quartz.JobBuilder;
import org.quartz.JobDetail;
import org.quartz.Trigger;
import org.quartz.TriggerBuilder;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import static org.quartz.CronScheduleBuilder.cronSchedule;

/**
 * @author xusirui 2022/4/13
 */
@Configuration
@EnableConfigurationProperties(MutableTriggerConfigProperties.class)
@Slf4j
public class QuartzTaskConfig {

    private final MutableTriggerConfigProperties properties;


    public QuartzTaskConfig(MutableTriggerConfigProperties properties) {
        this.properties = properties;
    }

    @Bean
    public JobDetail unbindJobDetail(){
        TriggerConfigurationProperties property = properties.getUnbindProperties();

        try {
            return JobBuilder.newJob(UnbindJob.class)
                    .withIdentity(property.getJobName(), property.getJobGroup())
                    .storeDurably()
                    .build();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("Create JobDetail bean failed:{},jobName->{},jobGroup->{}", e.getMessage(),property.getJobName(),property.getJobGroup());
        }
        return null;
    }

    @Bean
    public Trigger unbindJobTrigger() {
        TriggerConfigurationProperties property = properties.getUnbindProperties();
        try {
            return TriggerBuilder.newTrigger()
                    .forJob(property.getJobName(), property.getJobGroup())
                    .withSchedule(cronSchedule(property.getCronStr())).build();
        } catch (Exception e) {
            log.error("Create Trigger bean failed:{},jobName->{},jobGroup->{}", e.getMessage(),property.getJobName(),property.getJobGroup());
            throw e;
        }
    }

    @Bean
    public JobDetail pullTemplateTaskJobDetail(){
        TriggerConfigurationProperties property = properties.getPullTemplateTaskProperties();

        try {
            return JobBuilder.newJob(PullTemplateTaskJob.class)
                    .withIdentity(property.getJobName(), property.getJobGroup())
                    .storeDurably()
                    .build();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("Create JobDetail bean failed:{},jobName->{},jobGroup->{}", e.getMessage(),property.getJobName(),property.getJobGroup());
        }
        return null;
    }

    @Bean
    public Trigger pullTemplateTaskJobTrigger() {
        TriggerConfigurationProperties property = properties.getPullTemplateTaskProperties();
        try {
            return TriggerBuilder.newTrigger()
                    .forJob(property.getJobName(), property.getJobGroup())
                    .withSchedule(cronSchedule(property.getCronStr())).build();
        } catch (Exception e) {
            log.error("Create Trigger bean failed:{},jobName->{},jobGroup->{}", e.getMessage(),property.getJobName(),property.getJobGroup());
            throw e;
        }
    }

}
